
package audio;

import gui.BlueMIDlet;
import java.io.IOException;
import java.io.InputStream;
import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.media.Manager;
import javax.microedition.media.MediaException;
import javax.microedition.media.Player;

/**
 * This class will play the audio files needed for the game
 * There should be necessary control to play and stop audio from the 
 * midlet class. The play is done in a separate thread.
 * 
 * @author sumanta
 */
public class BlueAudio extends Thread{
    
    private BlueMIDlet parent;
    private String musicPath = null;
    private Player player;
    
    /**
     * constuctor
     * checks whether the platform has media support or not
     * @param parent
     */
    public BlueAudio(BlueMIDlet parent) {
        this.parent = parent;
        String version = System.getProperty("microedition.media.version");
        if(version == null)
             parent.switchDisplayable(new Alert("Error!", "Your device does not support Media API", 
                null, AlertType.ERROR), parent.getDisplay().getCurrent());
    }
    
    /**
     * set the path for the music to be played
     * the path should be relative to the jar root
     * e.g. /audio/sample.mid
     * @param musicPath
     */
    public void setMusicPath(String musicPath) {
        this.musicPath = musicPath;
    }
    
    /**
     * starting point of the thread
     * starts running a music file as indicated in path
     */
    public void run()
    {
        if(musicPath != null)
            play(musicPath, -1);
    }
    
    /**
     * main method to play music files
     * currently support midi and wave files
     * 
     * @param path
     * @param loopCount
     */
    public void play(String path, int loopCount)
    {
        String ext = path.substring(path.indexOf(".")+1, path.length());
        System.out.println(ext);
        String protocol = ext.equals("mid") ? "audio/midi":"audio/x-wav";
        try {
            InputStream in = getClass().getResourceAsStream(path);
            player = Manager.createPlayer(in, protocol);
            player.setLoopCount(loopCount);
            player.start();
        } catch (IOException ex) {
            ex.printStackTrace();
        } catch (MediaException ex) {
            ex.printStackTrace();
        }
    }
    
    /**
     * stops playing media file
     */
    public void stop()
    {
        try {
            player.stop();
        } catch (MediaException ex) {
            ex.printStackTrace();
        }
    }
    
    /**
     * closes the player and deallocates resources
     * should call it just before destroying the midlet
     */
    public void close()
    {
        player.deallocate();
        player = null;
    }
    
}
