
package connection;

import common.CommonVariables;
import gui.BlueMIDlet;
import java.io.IOException;
import javax.bluetooth.BluetoothStateException;
import javax.bluetooth.DeviceClass;
import javax.bluetooth.DiscoveryAgent;
import javax.bluetooth.DiscoveryListener;
import javax.bluetooth.LocalDevice;
import javax.bluetooth.RemoteDevice;
import javax.bluetooth.ServiceRecord;
import javax.bluetooth.UUID;
import javax.microedition.io.Connector;
import javax.microedition.io.StreamConnection;

/**
 * Main class for communication as a bluetooth client
 * Runs as a thread
 * 
 * @author sumanta
 */
public class BlueClient implements Runnable, DiscoveryListener {

    public UUID[] uuidSet;
    public RemoteDevice[] devices;
    public DiscoveryAgent agent;
    public String serviceUrl;
    private BlueMIDlet parent;

    /**
     * constructor. Takes argument parent for controllng the display if needed
     * initializes the localdevice and discovery mode
     * @param parent
     */
    public BlueClient(BlueMIDlet parent) {
        this.parent = parent;
        try {
            LocalDevice local = LocalDevice.getLocalDevice();
            agent = local.getDiscoveryAgent();
            local.setDiscoverable(DiscoveryAgent.GIAC);
        } catch (BluetoothStateException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

    }

    /**
     * starts the inquiry proces in a seperate thread
     */
    public void run() {
        try {
            agent.startInquiry(DiscoveryAgent.GIAC, this);
        } catch (BluetoothStateException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    /**
     * callback method for device discovered.
     * @todo show a list and let the user chose from the list of devices discovered
     * 
     * @param remote
     * @param devclass
     */
    public void deviceDiscovered(RemoteDevice remote, DeviceClass devclass) {
        try {
            //showing the user the friendly name of the discovered device. Helps him to choose.
            parent.getTxtConnection().setString(remote.getFriendlyName(true));
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

        //init service searching
        uuidSet = new UUID[1];
        uuidSet[0] = CommonVariables.MYUUID;
        try {
            int searchID = agent.searchServices(null, uuidSet, remote, this);
        } catch (BluetoothStateException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    public void inquiryCompleted(int arg0) {
    

    }

    /**
     * callback method
     * search complete, so we can start our game logic
     * 
     * @param transID
     * @param responseCode
     */
    public void serviceSearchCompleted(int transID, int responseCode) {
        try {
           
            StreamConnection conn = (StreamConnection) Connector.open(serviceUrl);
            CommonVariables.myTurn = false;
            CommonVariables.myName = "client";
            CommonVariables.myChar = 'O';
            
            CommonVariables.conn = conn;
            System.out.println("Connection client: " + conn);
            
            parent.switchDisplayable(null, parent.getTxtConnection());

            new ReadingThread(parent).start();
        } catch (IOException e) {
            
            e.printStackTrace();
        }

    }

    public void servicesDiscovered(int arg0, ServiceRecord[] arg1) {
        
        for (int i = 0; i < arg1.length; i++) {
            serviceUrl = arg1[i].getConnectionURL(0, false);
        }
    }
}
