package connection;

import common.CommonVariables;
import communication.ReadWrite;
import gui.BlueMIDlet;
import java.io.IOException;
import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Canvas;

/**
 * Reading from the bluetooth connection is a continuous process
 * So it should be done from a seperate thread
 * both the server and client needs reading capability
 * they will invoke this thread class for reading in background
 * 
 * @author sumanta
 */
public class ReadingThread extends Thread {

    BlueMIDlet parent;

    public ReadingThread(BlueMIDlet parent) {
        this.parent = parent;
    }

    /**
     * Thread entry point
     * the streams are initialized and used for busy checking whether anything
     * is available for reading or not
     * Based upon the read character or number
     * the thread decides what to do. Either it passes the read character to the 
     * game engine or it declares winning or drawn match
     */
    public void run() {
        while (true) {
            try {
                if (CommonVariables.in == null) {
                    CommonVariables.in = CommonVariables.conn.openInputStream();
                }
                if (CommonVariables.out == null) {
                    CommonVariables.out = CommonVariables.conn.openOutputStream();
                }
                String input = ReadWrite.read();
                //parent.getFrmChatting().append(input);

                try {
                    boolean valid = CommonVariables.engine.setMove(Integer.parseInt(input), false);
                    if (!valid) {
                        parent.switchDisplayable(new Alert("Error", "Invalid Move!", null, AlertType.ERROR),
                                parent.getGameCanvas());

                    } else {
                        CommonVariables.myTurn = true;
                        //parent.getTurnString().setText("Your turn");
                        ((Canvas)(parent.getGameCanvas())).repaint();
                    }
                } catch (NumberFormatException nfe) {
                    System.out.println("read from thread: "+input);
                    if (input.equals("win")) {
                        parent.switchDisplayable(new Alert("Your opponent won!!", "Sorry! You lost the game", null, AlertType.CONFIRMATION)
                                , parent.getTxtConnection());
                    }
                    //match tied
                    else if(input.equals("tie"))
                    {
                        parent.switchDisplayable(new Alert("Match Drawn!!", "This match has been tied", null, AlertType.INFO)
                                , parent.getTxtConnection());
                    }
                    //new button pressed by the peer, start new game
                    else if( input.equals("new")) {
                        CommonVariables.engine.init();
                        CommonVariables.myTurn = false;
                        ((Canvas)(parent.getGameCanvas())).repaint();
                    }
                }
            
            } catch (IOException ex) {
                System.out.println("Exception in read thread");
                ex.printStackTrace();
            }
        }

    }
}
